---
title: XPathResult
slug: Web/API/XPathResult
tags:
  - API
  - DOM XPath API
  - Interface
  - Reference
  - XPath
  - XPathResult
browser-compat: api.XPathResult
---
{{APIRef}}

The **`XPathResult`** interface represents the results generated by evaluating an XPath expression within the context of a given node.

Since XPath expressions can result in a variety of result types, this interface makes it possible to determine and handle the type and value of the result.

## Properties

- {{domxref("XPathResult.booleanValue")}}{{readonlyInline}}
  - : A `boolean` representing the value of the result if `resultType` is `BOOLEAN_TYPE`.
- {{domxref("XPathResult.invalidIteratorState")}}{{readonlyInline}}
  - : Signifies that the iterator has become invalid. It is `true` if `resultType` is `UNORDERED_NODE_ITERATOR_TYPE` or `ORDERED_NODE_ITERATOR_TYPE` and the document has been modified since this result was returned.
- {{domxref("XPathResult.numberValue")}}{{readonlyInline}}
  - : A `number` representing the value of the result if `resultType` is `NUMBER_TYPE`.
- {{domxref("XPathResult.resultType")}}{{readonlyInline}}
  - : A `number` code representing the type of the result, as defined by the type constants.
- {{domxref("XPathResult.singleNodeValue")}}{{readonlyInline}}
  - : A {{domxref("Node")}} representing the value of the single node result, which may be `null`.
- {{domxref("XPathResult.snapshotLength")}}{{readonlyInline}}
  - : The number of nodes in the result snapshot.
- {{domxref("XPathResult.stringValue")}}{{readonlyInline}}
  - : A {{domxref("DOMString", "string")}} representing the value of the result if `resultType` is `STRING_TYPE`.

## Methods

- {{domxref("XPathResult.iterateNext()")}}
  - : If the result is a node set, this method iterates over it and returns the next node from it or `null` if there are no more nodes.
- {{domxref("XPathResult.snapshotItem()")}}
  - : Returns an item of the snapshot collection or `null` in case the index is not within the range of nodes. Unlike the iterator result, the snapshot does not become invalid, but may not correspond to the current document if it is mutated.

## Constants

<table class="no-markdown">
  <thead>
    <tr>
      <th>Result Type Defined Constant</th>
      <th>Value</th>
      <th>Description</th>
    </tr>
  </thead>
  <tbody>
    <tr>
      <td><code>ANY_TYPE</code></td>
      <td><code>0</code></td>
      <td>
        A result set containing whatever type naturally results from evaluation
        of the expression. Note that if the result is a node-set then
        <code>UNORDERED_NODE_ITERATOR_TYPE</code> is always the resulting type.
      </td>
    </tr>
    <tr>
      <td><code>NUMBER_TYPE</code></td>
      <td><code>1</code></td>
      <td>
        A result containing a single number. This is useful for example, in an
        XPath expression using the <code>count()</code> function.
      </td>
    </tr>
    <tr>
      <td><code>STRING_TYPE</code></td>
      <td><code>2</code></td>
      <td>A result containing a single string.</td>
    </tr>
    <tr>
      <td><code>BOOLEAN_TYPE</code></td>
      <td><code>3</code></td>
      <td>
        A result containing a single boolean value. This is useful for example,
        in an XPath expression using the <code>not()</code> function.
      </td>
    </tr>
    <tr>
      <td><code>UNORDERED_NODE_ITERATOR_TYPE</code></td>
      <td><code>4</code></td>
      <td>
        A result node-set containing all the nodes matching the expression. The
        nodes may not necessarily be in the same order that they appear in the
        document.
      </td>
    </tr>
    <tr>
      <td><code>ORDERED_NODE_ITERATOR_TYPE</code></td>
      <td><code>5</code></td>
      <td>
        A result node-set containing all the nodes matching the expression. The
        nodes in the result set are in the same order that they appear in the
        document.
      </td>
    </tr>
    <tr>
      <td><code>UNORDERED_NODE_SNAPSHOT_TYPE</code></td>
      <td><code>6</code></td>
      <td>
        A result node-set containing snapshots of all the nodes matching the
        expression. The nodes may not necessarily be in the same order that they
        appear in the document.
      </td>
    </tr>
    <tr>
      <td><code>ORDERED_NODE_SNAPSHOT_TYPE</code></td>
      <td><code>7</code></td>
      <td>
        A result node-set containing snapshots of all the nodes matching the
        expression. The nodes in the result set are in the same order that they
        appear in the document.
      </td>
    </tr>
    <tr>
      <td><code>ANY_UNORDERED_NODE_TYPE</code></td>
      <td><code>8</code></td>
      <td>
        A result node-set containing any single node that matches the
        expression. The node is not necessarily the first node in the document
        that matches the expression.
      </td>
    </tr>
    <tr>
      <td><code>FIRST_ORDERED_NODE_TYPE</code></td>
      <td><code>9</code></td>
      <td>
        A result node-set containing the first node in the document that matches
        the expression.
      </td>
    </tr>
  </tbody>
</table>

## Specifications

{{Specifications}}

## Browser compatibility

{{Compat}}

## See also

- {{domxref("Document.evaluate()")}}
- {{domxref("XPathExpression")}}
- [Dottoro Web Reference - XPathResult object](http://help.dottoro.com/ljagksjc.php)
