---
title: Link types
slug: Web/HTML/Link_types
tags:
  - Attribute
  - HTML
  - Link
  - Link types
  - Reference
browser-compat: html.elements.link.rel
---

{{HTMLSidebar}}

In HTML, link types indicate the relationship between two documents, in which one links to the other using an {{HTMLElement("a")}}, {{HTMLElement("area")}}, {{HTMLElement("form")}}, or {{HTMLElement("link")}} element.

<table class="standard-table">
  <caption>
    List of the defined link types and their significance in HTML
  </caption>
  <thead>
    <tr>
      <th scope="col">Link Type</th>
      <th scope="col">Description</th>
      <th scope="col">Allowed in these elements</th>
      <th scope="col">Not allowed in these elements</th>
    </tr>
  </thead>
  <tbody>
    <tr>
      <td><code>alternate</code></td>
      <td>
        <ul>
          <li>
            If the element is {{HTMLElement("link")}} and the
            {{HTMLAttrxRef("rel", "link")}} attribute also contains the
            <code>stylesheet</code> type, the link defines an
            <a href="/en-US/docs/Web/CSS/Alternative_style_sheets"
              >alternative style sheet</a
            >; in that case the {{HTMLAttrxRef("title", "link")}}
            attribute must be present and not be the empty string.
          </li>
          <li>
            If the {{HTMLAttrxRef("type","link")}} is set to
            <code>application/rss+xml</code> or
            <code>application/atom+xml</code>, the link defines a
            <a href="/en-US/docs/Archive/RSS/Getting_Started/Syndicating"
              >syndication feed</a
            >. The first one defined on the page is the default.
          </li>
          <li>
            Otherwise, the link defines an alternative page, of one of these
            types:
            <ul>
              <li>
                for another medium, like a handheld device (if the
                {{HTMLAttrxRef("media","link")}} attribute is set)
              </li>
              <li>
                in another language (if the
                {{HTMLAttrxRef("hreflang","link")}} attribute is
                set),
              </li>
              <li>
                in another format, such as a PDF (if the
                {{HTMLAttrxRef("type","link")}} attribute is set)
              </li>
              <li>a combination of these</li>
            </ul>
          </li>
        </ul>
      </td>
      <td>
        {{HTMLElement("a")}}, {{HTMLElement("area")}},
        {{HTMLElement("link")}}
      </td>
      <td>{{HTMLElement("form")}}</td>
    </tr>
    <tr>
      <td><code>archives</code> {{deprecated_inline}}</td>
      <td>
        Defines a hyperlink to a document that contains an archive link to this
        one. For example, a blog entry could link to a monthly index page this
        way.<br /><br /><strong>Note:</strong> Although recognized, the singular
        <code>archive</code> is incorrect and must be avoided.
      </td>
      <td>
        {{HTMLElement("a")}}, {{HTMLElement("area")}},
        {{HTMLElement("link")}}
      </td>
      <td>{{HTMLElement("form")}}</td>
    </tr>
    <tr>
      <td><code>author</code></td>
      <td>
        Defines a hyperlink to a page describing the author or providing a way
        to contact the author.<br /><br /><strong>Note:</strong> This may be a
        <code>mailto:</code> hyperlink, but this is not recommended on public
        pages as robot harvesters will quickly lead to a lot of spam sent to the
        address. In that case, it is better to lead to a page containing a
        contact form.<br /><br />Although recognized, the
        {{HTMLAttrxRef("rev", "link")}} attribute on
        {{HTMLElement("a")}}, {{HTMLElement("area")}}
        or{{HTMLElement("link")}} elements with a link type of
        <code>made</code> is incorrect and should be replaced by the
        {{HTMLAttrxRef("rel", "link")}} attribute with this link type.
      </td>
      <td>
        {{HTMLElement("a")}}, {{HTMLElement("area")}},
        {{HTMLElement("link")}}
      </td>
      <td>{{HTMLElement("form")}}</td>
    </tr>
    <tr>
      <td><code>bookmark</code></td>
      <td>
        Indicates that the hyperlink is a
        <a href="/en-US/docs/Permalink">permalink</a> for the nearest ancestor
        {{HTMLElement("article")}} element. If none, it is a permalink
        for the
        <a href="/en-US/docs/Web/HTML/Element/Heading_Elements">section</a> that
        the element is most closely associated to.<br /><br />This allows for
        bookmarking a single article in a page containing multiple articles,
        such as on a monthly summary blog page, or a blog aggregator.
      </td>
      <td>{{HTMLElement("a")}}, {{HTMLElement("area")}}</td>
      <td>
        {{HTMLElement("link")}}, {{HTMLElement("form")}}
      </td>
    </tr>
    <tr>
      <td><code>canonical</code></td>
      <td>
        From Wikipedia, the free encyclopedia:
        <a href="https://en.wikipedia.org/wiki/Canonical_link_element"
          >Canonical_link_element</a
        ><br />A canonical link element is an HTML element that helps webmasters
        prevent duplicate content issues by specifying the "canonical" or
        "preferred" version of a web page as part of search engine optimization.
      </td>
      <td>{{HTMLElement("link")}}</td>
      <td>
        {{HTMLElement("a")}}, {{HTMLElement("area")}},
        {{HTMLElement("form")}}
      </td>
    </tr>
    <tr>
      <td>
        <code
          ><a href="/en-US/docs/Web/HTML/Link_types/dns-prefetch"
            >dns-prefetch</a
          ></code
        >
        {{Experimental_Inline}}
      </td>
      <td>
        Hints to the browser that a resource is needed, allowing the browser to
        do a DNS lookup and protocol handshaking before a user clicks the link.
      </td>
      <td>{{HTMLElement("link")}}</td>
      <td>
        {{HTMLElement("a")}}, {{HTMLElement("area")}},
        {{HTMLElement("form")}}
      </td>
    </tr>
    <tr>
      <td><code>external</code></td>
      <td>
        Indicates that the hyperlink leads to a resource outside the site of the
        current page; that is, following the link will make the user leave the
        site.
      </td>
      <td>
        {{HTMLElement("a")}}, {{HTMLElement("area")}},
        {{HTMLElement("form")}}
      </td>
      <td>{{HTMLElement("link")}}</td>
    </tr>
    <tr>
      <td><code>first</code> {{deprecated_inline}}</td>
      <td>
        Indicates that the hyperlink leads to the first resource of the
        <em>sequence</em> the current page is in.<br /><br /><strong
          >Note:</strong
        >
        Other link types related to linking resources in the same sequence are
        <code>last</code>, <code>prev</code>,
        <code>next</code>.<br /><br />Although recognized, the synonyms
        <code>begin</code> and <code>start</code> are incorrect and must be
        avoided.
      </td>
      <td>
        {{HTMLElement("a")}}, {{HTMLElement("area")}},
        {{HTMLElement("link")}}
      </td>
      <td>{{HTMLElement("form")}}</td>
    </tr>
    <tr>
      <td><code>help</code></td>
      <td>
        <ul>
          <li>
            If the element is {{HTMLElement("a")}} or
            {{HTMLElement("area")}}, it indicates that the hyperlink
            leads to a resource giving further help about the parent of the
            element, and its descendants.
          </li>
          <li>
            If the element is {{HTMLElement("link")}} it indicates that
            the hyperlink leads to a resource giving further help about the page
            as a whole.
          </li>
        </ul>
      </td>
      <td>
        {{HTMLElement("a")}}, {{HTMLElement("area")}},
        {{HTMLElement("form")}}, {{HTMLElement("link")}}
      </td>
      <td><em>None.</em></td>
    </tr>
    <tr>
      <td><code>icon</code></td>
      <td>
        Defines a resource for representing the page in the user interface,
        usually an icon (auditory or visual). In the browser, it is usually
        referred to as the {{glossary("Favicon", "favicon")}}.<br /><br />If
        there are multiple <code>&#x3C;link rel="icon"></code>s, the browser
        uses their {{HTMLAttrxRef("media","link")}},
        {{HTMLAttrxRef("type","link")}}, and
        {{HTMLAttrxRef("sizes","link")}} attributes to select the
        most appropriate icon. If several icons are equally appropriate, the
        last one is used. If the most appropriate icon is later found to be
        inappropriate, for example because it uses an unsupported format, the
        browser proceeds to the next-most appropriate, and so on.<br /><br />
        <div class="notecard note">
          <p>
            <strong>Note:</strong> Apple's iOS does not use this link type, nor
            the {{HTMLAttrxRef("sizes","link")}} attribute, like
            others mobile browsers do, to select a webpage icon for Web Clip or
            a start-up placeholder. Instead it uses the non-standard
            <a
              class="external external-icon"
              href="https://developer.apple.com/library/content/documentation/AppleApplications/Reference/SafariWebContent/ConfiguringWebApplications/ConfiguringWebApplications.html#//apple_ref/doc/uid/TP40002051-CH3-SW4"
              ><code>apple-touch-icon</code></a
            >
            and
            <a
              class="external external-icon"
              href="https://developer.apple.com/library/content/documentation/AppleApplications/Reference/SafariWebContent/ConfiguringWebApplications/ConfiguringWebApplications.html#//apple_ref/doc/uid/TP40002051-CH3-SW6"
              ><code>apple-touch-startup-image</code></a
            >
            respectively.
          </p>
        </div>
        <div class="notecard warning">
          <p>
            <strong>Warning:</strong> The <code>shortcut</code> link type is
            often seen before <code>icon</code>, but this link type is
            non-conforming, ignored and
            <strong>web authors must not use it anymore</strong>.
          </p>
        </div>
      </td>
      <td>{{HTMLElement("link")}}</td>
      <td>
        {{HTMLElement("a")}}, {{HTMLElement("area")}},
        {{HTMLElement("form")}}
      </td>
    </tr>
    <tr>
      <td><code>index</code> {{deprecated_inline}}</td>
      <td>
        Indicates that the page is part of a <em>hierarchical</em> structure and
        that the hyperlink leads to the top level resource of that structure.<br /><br />If
        one or several <code>up</code> link types are also present, the number
        of these <code>up</code> indicates the depth of the current page in the
        hierarchy.
      </td>
      <td>
        {{HTMLElement("a")}}, {{HTMLElement("area")}},
        {{HTMLElement("link")}}
      </td>
      <td>{{HTMLElement("form")}}</td>
    </tr>
    <tr>
      <td><code>last</code> {{deprecated_inline}}</td>
      <td>
        Indicates that the hyperlink leads to the <em>last</em> resource of the
        <em>sequence</em> the current page is in.<br /><br /><strong
          >Note:</strong
        >
        Other link types related to linking resources in the same sequence are
        <code>first</code>, <code>prev</code>,
        <code>next</code>.<br /><br />Although recognized, the synonym
        <code>end</code> is incorrect and must be avoided.
      </td>
      <td>
        {{HTMLElement("a")}}, {{HTMLElement("area")}},
        {{HTMLElement("link")}}
      </td>
      <td>{{HTMLElement("form")}}</td>
    </tr>
    <tr>
      <td><code>license</code></td>
      <td>
        Indicates that the hyperlink leads to a document describing the
        licensing information. If not inside the
        {{HTMLElement("head")}} element, the standard doesn't
        distinguish between a hyperlink applying to a specific part of the
        document or to the document as a whole. Only the data on the page can
        indicate this.<br /><br /><strong>Note:</strong> Although recognized,
        the synonym <code>copyright</code> is incorrect and must be avoided.
      </td>
      <td>
        {{HTMLElement("a")}}, {{HTMLElement("area")}},
        {{HTMLElement("form")}}, {{HTMLElement("link")}}
      </td>
      <td><em>None.</em></td>
    </tr>
    <tr>
      <td>
        <code
          ><a href="/en-US/docs/Web/HTML/Link_types/manifest">manifest</a></code
        >
      </td>
      <td>
        Indicates that the linked file is a
        <a href="/en-US/docs/Web/Manifest">Web App Manifest</a>.
      </td>
      <td>{{HTMLElement("link")}}</td>
      <td>
        {{HTMLElement("a")}}, {{HTMLElement("area")}},
        {{HTMLElement("form")}}
      </td>
    </tr>
    <tr>
      <td>
        <code
          ><a href="/en-US/docs/Web/HTML/Link_types/me">me</a></code
        >
      </td>
      <td>
        Indicates that the current document is represented by the person to which
        the me value links. The me value is commonly used in distributed forms
        of verification such as <a href="https://microformats.org/wiki/RelMeAuth">
        RelMeAuth</a>.
      </td>
      <td>{{HTMLElement("link")}}, {{HTMLElement("a")}}</td>
      <td>
        {{HTMLElement("area")}}, {{HTMLElement("form")}}
      </td>
    </tr>
    <tr>
      <td>
        <code
          ><a href="/en-US/docs/Web/HTML/Link_types/modulepreload"
            >modulepreload</a
          ></code
        >
      </td>
      <td>Initiates early (and high-priority) loading of module scripts.</td>
      <td>{{HTMLElement("link")}}</td>
      <td>
        {{HTMLElement("a")}}, {{HTMLElement("area")}},
        {{HTMLElement("form")}}
      </td>
    </tr>
    <tr>
      <td><code>next</code></td>
      <td>
        Indicates that the hyperlink leads to the <em>next</em> resource of the
        <em>sequence</em> the current page is in.<br /><br /><strong
          >Note:</strong
        >
        Other link types related to linking resources in the same sequence are
        <code>first</code>, <code>prev</code>, <code>last</code>.
      </td>
      <td>
        {{HTMLElement("a")}}, {{HTMLElement("area")}},
        {{HTMLElement("form")}}, {{HTMLElement("link")}}
      </td>
      <td><em>None.</em></td>
    </tr>
    <tr>
      <td><code>nofollow</code></td>
      <td>
        Indicates that the linked document is not endorsed by the author of this
        one, for example if it has no control over it, if it is a bad example or
        if there is commercial relationship between the two (sold link). This
        link type may be used by some search engines that use popularity ranking
        techniques.
      </td>
      <td>
        {{HTMLElement("a")}}, {{HTMLElement("area")}},
        {{HTMLElement("form")}}
      </td>
      <td>{{HTMLElement("link")}}</td>
    </tr>
    <tr>
      <td>
        <code
          ><a href="/en-US/docs/Web/HTML/Link_types/noopener">noopener</a></code
        >
      </td>
      <td>
        <p>
          Instructs the browser to open the link without granting the new
          browsing context access to the document that opened it — by not
          setting the {{DOMxRef("Window.opener")}} property on the
          opened window (it returns <code>null</code>).<br /><br />This is
          especially useful when opening untrusted links, in order to ensure
          they cannot tamper with the originating document via the
          {{DOMxRef("Window.opener")}} property (see
          <a href="https://mathiasbynens.github.io/rel-noopener/"
            >About rel=noopener</a
          >
          for more details), while still providing the <code>Referer</code> HTTP
          header (unless <code>noreferrer</code> is used as well).
        </p>
        <p>
          Note that when <code>noopener</code> is used, nonempty target names
          other than <code>_top</code>, <code>_self</code>, and
          <code>_parent</code> are all treated like <code>_blank</code> in terms
          of deciding whether to open a new window/tab.
        </p>
      </td>
      <td>
        {{HTMLElement("a")}}, {{HTMLElement("area")}},
        {{HTMLElement("form")}}
      </td>
      <td>{{HTMLElement("link")}}</td>
    </tr>
    <tr>
      <td>
        <code
          ><a href="/en-US/docs/Web/HTML/Link_types/noreferrer"
            >noreferrer</a
          ></code
        >
      </td>
      <td>
        <p>
          Prevents the browser, when navigating to another page, to send this
          page address, or any other value, as referrer via the
          <code>Referer:</code> HTTP header.<br />(In Firefox, before Firefox
          37, this worked only in links found in pages. Links clicked in the UI,
          like "Open in a new tab" via the contextual menu, ignored this).
        </p>
      </td>
      <td>
        {{HTMLElement("a")}}, {{HTMLElement("area")}},
        {{HTMLElement("form")}}
      </td>
      <td>{{HTMLElement("link")}}</td>
    </tr>
    <tr>
      <td><code>opener</code> {{Experimental_Inline}}</td>
      <td>
        <p>
          Reverts implicit <code>rel="noopener"</code> addition on links with
          <code>target="_blank"</code> (See
          <a href="https://github.com/whatwg/html/issues/4078"
            >related HTML spec discussion</a
          >,
          <a href="https://trac.webkit.org/changeset/237144/webkit/"
            >WebKit change</a
          >, and
          <a href="https://bugzilla.mozilla.org/show_bug.cgi?id=1503681"
            >Firefox bug discussion</a
          >).
        </p>
      </td>
      <td>
        {{HTMLElement("a")}}, {{HTMLElement("area")}},
        {{HTMLElement("form")}}
      </td>
      <td>{{HTMLElement("link")}}</td>
    </tr>
    <tr>
      <td><code>pingback</code></td>
      <td>
        Defines an external resource URI to call if one wishes to make a comment
        or a citation about the webpage. The protocol used to make such a call
        is defined in the
        <a href="https://www.hixie.ch/specs/pingback/pingback">Pingback 1.0</a>
        specification.<br /><br /><strong>Note:</strong> if the
        <code>X-Pingback:</code> HTTP header is also present, it supersedes the
        {{HTMLElement("link")}} element with this link type.
      </td>
      <td>{{HTMLElement("link")}}</td>
      <td>
        {{HTMLElement("a")}}, {{HTMLElement("area")}},
        {{HTMLElement("form")}}
      </td>
    </tr>
    <tr>
      <td>
        <code
          ><a href="/en-US/docs/Web/HTML/Link_types/preconnect"
            >preconnect</a
          ></code
        >
        {{Experimental_Inline}}
      </td>
      <td>
        Provides a hint to the browser suggesting that it open a connection to
        the linked web site in advance, without disclosing any private
        information or downloading any content, so that when the link is
        followed the linked content can be fetched more quickly.
      </td>
      <td>{{HTMLElement("link")}}</td>
      <td>
        {{HTMLElement("a")}}, {{HTMLElement("area")}},
        {{HTMLElement("form")}}
      </td>
    </tr>
    <tr>
      <td>
        <code
          ><a href="/en-US/docs/Web/HTML/Link_types/prefetch">prefetch</a></code
        >
      </td>
      <td>
        Suggests that the browser fetch the linked resource in advance, as it is
        likely to be requested by the user. Starting with Firefox 44, the value
        of the {{HTMLAttrxRef("crossorigin", "link")}} attribute is
        taken into consideration, making it possible to make anonymous
        prefetches.<br /><br /><strong>Note:</strong> The
        <a href="/en-US/docs/Web/HTTP/Link_prefetching_FAQ"
          >Link Prefetch FAQ</a
        >
        has details on which links can be prefetched and on alternative methods.
      </td>
      <td>{{HTMLElement("link")}}</td>
      <td>
        {{HTMLElement("a")}}, {{HTMLElement("area")}},
        {{HTMLElement("form")}}
      </td>
    </tr>
    <tr>
      <td>
        <code
          ><a href="/en-US/docs/Web/HTML/Link_types/preload">preload</a></code
        >
      </td>
      <td>
        Tells the browser to download a resource because this resource will be
        needed later during the current navigation. See
        <a href="/en-US/docs/Web/HTML/Link_types/preload"
          >Preloading content with rel="preload"</a
        >
        for more details.
      </td>
      <td>{{HTMLElement("link")}}</td>
      <td>
        {{HTMLElement("a")}}, {{HTMLElement("area")}},
        {{HTMLElement("form")}}
      </td>
    </tr>
    <tr>
      <td>
        <code
          ><a href="/en-US/docs/Web/HTML/Link_types/prerender"
            >prerender</a
          ></code
        >
        {{Experimental_Inline}}
      </td>
      <td>
        Suggests that the browser fetch the linked resource in advance, and that
        it also render the prefetched content offscreen so it can be quickly
        presented to the user once needed.
      </td>
      <td>{{HTMLElement("link")}}</td>
      <td>
        {{HTMLElement("a")}}, {{HTMLElement("area")}},
        {{HTMLElement("form")}}
      </td>
    </tr>
    <tr>
      <td><code>prev</code></td>
      <td>
        Indicates that the hyperlink leads to the <em>preceding</em> resource of
        the <em>sequence</em> the current page is in.<br /><br /><strong
          >Note:</strong
        >
        You can also use the <code>next</code> keyword to specify a link to the
        next page in the sequence.<br /><br />Although recognized, the synonym
        <code>previous</code> is incorrect and must be avoided.
      </td>
      <td>
        {{HTMLElement("a")}}, {{HTMLElement("area")}},
        {{HTMLElement("link")}}, {{HTMLElement("form")}}
      </td>
      <td><em>None.</em></td>
    </tr>
    <tr>
      <td><code>search</code></td>
      <td>
        Indicates that the hyperlink references a document whose interface is
        specially designed for searching in this document, or site, and its
        resources.<br /><br />If the {{HTMLAttrxRef("type","link")}}
        attribute is set to
        <code>application/opensearchdescription+xml </code>the resource is an
        <a href="/en-US/docs/Web/OpenSearch">OpenSearch plugin</a> that can be
        easily added to the interface of some browsers like Firefox or Internet
        Explorer.
      </td>
      <td>
        {{HTMLElement("a")}}, {{HTMLElement("area")}},
        {{HTMLElement("link")}}, {{HTMLElement("form")}}
      </td>
      <td><em>None.</em></td>
    </tr>
    <tr>
      <td><code>shortlink</code></td>
      <td>
        <a
          href="https://code.google.com/archive/p/shortlink/wikis/Specification.wiki"
          ><code>shortlink</code> Specification</a
        ><br />From Wikipedia, the free encyclopedia:
        <a href="https://en.wikipedia.org/wiki/URL_shortening">URL shortening</a
        ><br />Some websites create short links to make sharing links via
        instant messaging easier.
      </td>
      <td>{{HTMLElement("link")}}</td>
      <td>???</td>
    </tr>
    <tr>
      <td>
        <code>sidebar</code>
        {{Non-standard_Inline}}{{deprecated_inline}}
      </td>
      <td>
        Indicates that the hyperlink leads to a resource that would be better
        suited for a secondary browsing context, like a <em>sidebar</em>.
        Browsers, that don't have such a context will ignore this keyword.<br /><br />While
        once part of the HTML specification, this has been removed from the spec
        and is only implemented by versions of Firefox prior to Firefox 63.
      </td>
      <td>
        {{HTMLElement("a")}}, {{HTMLElement("area")}},
        {{HTMLElement("link")}}
      </td>
      <td>{{HTMLElement("form")}}</td>
    </tr>
    <tr>
      <td><code>stylesheet</code></td>
      <td>
        Defines an external resource to be used as a stylesheet. If the
        <code>type</code> is not set, the browser should assume it is a
        <code>text/css</code> stylesheet until further inspection.<br /><br />If
        used in combination with the <code>alternate</code> keyword, it defines
        an
        <a href="/en-US/docs/Web/CSS/Alternative_style_sheets"
          >alternative style sheet</a
        >; in that case the {{HTMLAttrxRef("title", "link")}}
        attribute must be present and not be the empty string.
      </td>
      <td>{{HTMLElement("link")}}</td>
      <td>
        {{HTMLElement("a")}}, {{HTMLElement("area")}},
        {{HTMLElement("form")}}
      </td>
    </tr>
    <tr>
      <td><code>tag</code></td>
      <td>
        Indicates that the hyperlink refers to a document describing a
        <em>tag</em> that applies to this document.<br /><br /><strong
          >Note:</strong
        >
        This link type should not be set on links to a member of a tag cloud as
        these do not apply to a single document but to a set of pages.
      </td>
      <td>{{HTMLElement("a")}}, {{HTMLElement("area")}}</td>
      <td>
        {{HTMLElement("link")}}, {{HTMLElement("form")}}
      </td>
    </tr>
    <tr>
      <td><code>up</code> {{deprecated_inline}}</td>
      <td>
        Indicates that the page is part of a <em>hierarchical</em> structure and
        that the hyperlink leads to the higher level resource of that
        structure.<br /><br />The number of <code>up</code> link types indicates
        the depth difference between the current page and the linked resource.
      </td>
      <td>
        {{HTMLElement("a")}}, {{HTMLElement("area")}},
        {{HTMLElement("link")}}
      </td>
      <td>{{HTMLElement("form")}}</td>
    </tr>
  </tbody>
</table>

## Specifications

{{Specifications}}

## Browser compatibility

{{Compat}}
