---
title: Progressive web apps (PWAs)
slug: Web/Progressive_web_apps
tags:
  - App
  - Application
  - Apps
  - PWA
  - Progressive web apps
  - Web app
  - Web applications
---
**Progressive Web Apps** (PWAs) are web apps that use [service workers](/en-US/docs/Web/API/Service_Worker_API), [manifests](/en-US/docs/Web/Manifest), and other web-platform features in combination with {{glossary("progressive enhancement")}} to give users an experience on par with native apps.

PWAs provide a number of [advantages](/en-US/docs/Web/Progressive_web_apps/Introduction#advantages_of_web_applications) to users — including being [installable](/en-US/docs/Web/Progressive_web_apps/Introduction#installability), [progressively enhanced](/en-US/docs/Web/Progressive_web_apps/Introduction#progressive_enhancement_support), [responsively designed](/en-US/docs/Web/Progressive_web_apps/Introduction#responsiveness), [re-engageable](/en-US/docs/Web/Progressive_web_apps/Introduction#re-engageability), [linkable](/en-US/docs/Web/Progressive_web_apps/Introduction#linkability), [discoverable](/en-US/docs/Web/Progressive_web_apps/Introduction#discoverability), [network independent](/en-US/docs/Web/Progressive_web_apps/Introduction#network_independence), and [secure](/en-US/docs/Web/Progressive_web_apps/Introduction#secure).

## PWA how-to guides and other documentation

These introductory materials and step-by-step guides walk you through key aspects of building PWAs:

- [Introduction to progressive web apps](/en-US/docs/Web/Progressive_web_apps/Introduction)
- [Progressive web app structure](/en-US/docs/Web/Progressive_web_apps/App_structure) and [structural overview](/en-US/docs/Web/Progressive_web_apps/Structural_overview)
- [Understanding the building blocks of responsive design](/en-US/docs/Web/Progressive_web_apps/Responsive/responsive_design_building_blocks)
- [How to make PWAs work offline (using service workers)](/en-US/docs/Web/Progressive_web_apps/Offline_Service_workers)
- [How to make PWAs installable](/en-US/docs/Web/Progressive_web_apps/Installable_PWAs), [enable "add to home screen"](/en-US/docs/Web/Progressive_web_apps/Add_to_home_screen), and [further details on installing PWAs](/en-US/docs/Web/Progressive_web_apps/Installing)
- [How to make PWAs "re-engageable" (using the Notifications API and Push API)](/en-US/docs/Web/Progressive_web_apps/Re-engageable_Notifications_Push)
- [How to enable progressive loading](/en-US/docs/Web/Progressive_web_apps/Loading)
- [How to build "mobile first" PWAs](/en-US/docs/Web/Progressive_web_apps/Responsive/Mobile_first)
- [Using service workers](/en-US/docs/Web/API/Service_Worker_API/Using_Service_Workers)
- [Using client-side storage](/en-US/docs/Learn/JavaScript/Client-side_web_APIs/Client-side_storage), [IndexedDB](/en-US/docs/Web/API/IndexedDB_API/Using_IndexedDB), and the [the Web Storage API](/en-US/docs/Web/API/Web_Storage_API/Using_the_Web_Storage_API)
- [Using the Notifications API](/en-US/docs/Web/API/Notifications_API/Using_the_Notifications_API) and [the Push API](/en-US/docs/Web/API/Push_API)

## See also

- [Progressive Web Apps landing page](https://web.dev/progressive-web-apps/) and [check list](https://web.dev/pwa-checklist/) on [web.dev](https://web.dev/)
- [Progressive Web Apps: Everything You Need To Know](https://www.csschopper.com/blog/progressive-web-apps-everything-you-need-to-know/)
- [Progressive Web Apps: Escaping Tabs Without Losing Our Soul](https://medium.com/@slightlylate/progressive-apps-escaping-tabs-without-losing-our-soul-3b93a8561955#.6czgj0myh)
- [Instant Loading Web Apps with An Application Shell Architecture](https://developers.google.com/web/updates/2015/11/app-shell)
- [Introduction to Progressive Web App Architectures](https://developers.google.com/web/ilt/pwa/introduction-to-progressive-web-app-architectures)
- [Workbox](https://developers.google.com/web/tools/workbox) — set of libraries to power a "production-ready" service worker for your PWA
- [Lighthouse](https://developers.google.com/web/tools/lighthouse) — web-app auditing tool that includes PWA-auditing features
- [localForage](https://localforage.github.io/localForage/) — `localStorage`-like _async_ storage, to improve your PWA's offline experience

{{QuickLinksWithSubpages("/en-US/docs/Web/Progressive_web_apps/")}}
